==> ktorrent-4.2.1.tar.xz: ktorrent-4.2.1/plugins/stats/DisplaySettingsPage.cc <==
/***************************************************************************
 *   Copyright (C) 2007 by Joris Guisson and Ivan Vasic                    *
 *   joris.guisson@gmail.com                                               *
 *   ivasic@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#include <statspluginsettings.h>
#include "DisplaySettingsPage.h"

namespace kt
{

	DisplaySettingsPage::DisplaySettingsPage(QWidget* parent)
			: PrefPageInterface(StatsPluginSettings::self(), i18n("Display"), "view-statistics", parent)
	{
		setupUi(this);
	}


	DisplaySettingsPage::~DisplaySettingsPage()
	{
	}


}

==> ktorrent-5.0.1.tar.xz: ktorrent-5.0.1/plugins/stats/DisplaySettingsPage.cc <==
/***************************************************************************
 *   Copyright (C) 2007 by Joris Guisson and Ivan Vasic                    *
 *   joris.guisson@gmail.com                                               *
 *   ivasic@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#include <statspluginsettings.h>
#include "DisplaySettingsPage.h"

namespace kt
{

    DisplaySettingsPage::DisplaySettingsPage(QWidget* parent)
        : PrefPageInterface(StatsPluginSettings::self(), i18nc("@title:window", "Display"), "view-statistics", parent)
    {
        setupUi(this);
    }


    DisplaySettingsPage::~DisplaySettingsPage()
    {
    }


}
